@@ -181,6 +181,7 @@ class Resolver:
     _log_unresolved = attr.ib(type=Set[Tuple[str, str, str]], default=attr.Factory(set), kw_only=True)
     _log_unsolved = attr.ib(type=Set[str], default=attr.Factory(set), kw_only=True)
     _log_sieved = attr.ib(type=Set[str], default=attr.Factory(set), kw_only=True)
+    _log_step_skip_package = attr.ib(type=Set[Tuple[str, str, str]], default=attr.Factory(set), kw_only=True)
     _log_step_not_acceptable = attr.ib(type=Set[Tuple[str, str, str]], default=attr.Factory(set), kw_only=True)
     _log_no_intersected = attr.ib(type=Set[Tuple[Tuple[str, str, str], str]], default=attr.Factory(set), kw_only=True)
 
@@ -315,6 +316,7 @@ class Resolver:
 
         score_addition = 0.0
         justification_addition = []
+        skip_package = False
         for step in self.pipeline.steps:
             _LOGGER.debug("Running step %r for %r", step.__class__.__name__, package_version_tuple)
 
@@ -329,6 +331,20 @@ class Resolver:
 
             try:
                 step_result = step.run(state, package_version)
+            except SkipPackage as exc:
+                # This should be fine also for user-stacks steps. They will just adjusted.
+                log_once(
+                    _LOGGER,
+                    self._log_step_skip_package,
+                    package_version_tuple,
+                    "Step %r discarded addition of package %r: %s",
+                    step.__class__.__name__,
+                    package_version_tuple,
+                    str(exc),
+                    level=log_level,
+                )
+                skip_package = True
+                break
             except NotAcceptable as exc:
                 log_once(
                     _LOGGER,
@@ -384,25 +400,33 @@ class Resolver:
                 if step_justification_addition is not None:
                     justification_addition.extend(step_justification_addition)
 
-        if state.unresolved_dependencies and package_version_tuple[0] in state.unresolved_dependencies:
+        if (
+            state.unresolved_dependencies
+            and package_version_tuple[0] in state.unresolved_dependencies
+            and not skip_package
+        ):
             cloned_state = state.clone()
             weakref.finalize(cloned_state, self.predictor.finalize_state, id(cloned_state)).atexit = False
         else:
             # Optimization - reuse the old one as it would be discarded anyway.
             cloned_state = state
-            if not user_stack_scoring and (
-                score_addition != 0.0 or (not state.unresolved_dependencies and not unresolved_dependencies)
+            if (
+                not user_stack_scoring
+                and not skip_package
+                and (score_addition != 0.0 or (not state.unresolved_dependencies and not unresolved_dependencies))
             ):
                 self.beam.remove(cloned_state)
 
-        if unresolved_dependencies:
+        if unresolved_dependencies and not skip_package:
             cloned_state.set_unresolved_dependencies(unresolved_dependencies)
 
         cloned_state.remove_unresolved_dependency_subtree(package_version_tuple[0])
-        cloned_state.add_resolved_dependency(package_version_tuple)
+        if not skip_package:
+            cloned_state.add_justification(justification_addition)
+            cloned_state.add_resolved_dependency(package_version_tuple)
+            cloned_state.score += score_addition
+
         cloned_state.iteration = self.context.iteration
-        cloned_state.add_justification(justification_addition)
-        cloned_state.score += score_addition
 
         if not user_stack_scoring:
             if cloned_state.unresolved_dependencies:
@@ -507,13 +531,13 @@ class Resolver:
         try to find a better stack than the one user is using.
         """
         if not self.project.pipfile_lock:
-            _LOGGER.info("Cannot score user's stack - no user's stack provided")
+            _LOGGER.info("Cannot score user's stack - no user's stack provided - see %s", jl("user_stack"))
             return None
 
         self._prepare_user_lock_file(with_devel=True)
 
         skipped_packages: List[PackageVersion] = []
-        _LOGGER.info("Scoring user's stack based on the lock file submitted")
+        _LOGGER.info("Scoring user's stack based on the lock file submitted - see %s", jl("user_stack"))
         for package_version in self.project.iter_dependencies_locked(with_devel=with_devel):
             # First time seen, register this package for pipeline units.
             self.context.register_package_version(package_version)
@@ -525,7 +549,7 @@ class Resolver:
                 continue
 
             if not package_version:
-                _LOGGER.info("User's stack was removed based on sieves")
+                _LOGGER.info("User's stack was removed based on sieves - see %s", jl("rm_user_stack"))
                 return None
 
         for skipped_package in skipped_packages:
@@ -548,7 +572,7 @@ class Resolver:
         state = State()
         for package_version in self.project.iter_dependencies_locked(with_devel=with_devel):
             if not self._run_steps(state, package_version, user_stack_scoring=True, log_level=logging.INFO):
-                _LOGGER.info("User's stack was removed based on steps")
+                _LOGGER.info("User's stack was removed based on steps - see %s", jl("rm_user_stack"))
                 return None
 
         state.add_justification(
@@ -562,7 +586,7 @@ class Resolver:
         )
         self._run_wraps(state)
         self.beam.add_state(state)
-        _LOGGER.info("User's software stack has a score of %g", state.score)
+        _LOGGER.info("User's software stack has a score of %g - see %s", state.score, jl("user_stack"))
         return state
 
     def _resolve_direct_dependencies(self, *, with_devel: bool) -> Dict[str, List[PackageVersion]]:
@@ -582,7 +606,10 @@ class Resolver:
                 # database but none was matching the given version range.
                 unresolved.append(package_version.name)
 
-                error_msg = f"No versions were found for direct dependency {package_version.name!r}"
+                error_msg = (
+                    f"No versions were found for direct dependency "
+                    f"{package_version.name!r} - see {jl('solve_direct')}"
+                )
                 runtime_environment = self.project.runtime_environment
                 if runtime_environment.operating_system.name:
                     error_msg += f"; operating system {runtime_environment.operating_system.name!r}"
@@ -950,9 +977,12 @@ class Resolver:
 
         if not self.project.runtime_environment.is_fully_specified():
             _LOGGER.warning(
-                "Environment is not fully specified, pre-computed environment markers will not be " "taken into account"
+                "Environment is not fully specified, pre-computed environment markers will "
+                "not be taken into account - see %s",
+                jl("spec_env"),
             )
 
+        _LOGGER.info("Scoring user's stack - see %s", jl("user_stack"))
         if user_stack_scoring:
             try:
                 user_stack = self._maybe_score_user_lock_file(with_devel=with_devel)
@@ -984,8 +1014,9 @@ class Resolver:
 
                 if self.beam.size == 0:
                     _LOGGER.warning(
-                        "No more possible paths found for resolution, terminating resolver in iteration %d",
+                        "No more possible paths found for resolution, terminating resolver in iteration %d, see - %s",
                         self.context.iteration,
+                        jl("no_paths"),
                     )
                     break
 
@@ -1089,8 +1120,8 @@ class Resolver:
 
             if report.product_count() == 0:
                 raise CannotProduceStack(
-                    "Resolver did not find any stack that would satisfy "
-                    "requirements and stack characteristics given the time allocated"
+                    f"Resolver did not find any stack that would satisfy "
+                    f"requirements and stack characteristics given the time allocated - see {jl('no_stack')}"
                 )
 
             if self.context.stack_info:
