@@ -18,9 +18,10 @@
 """Filter out stacks which have require non-existent ABI symbols."""
 
 import logging
-from typing import Any, Dict, Optional, Generator, Set, TYPE_CHECKING
+from typing import Any, Dict, Optional, Generator, Set, TYPE_CHECKING, Tuple
 
 import attr
+from thoth.common import get_justification_link as jl
 from thoth.python import PackageVersion
 
 from ..sieve import Sieve
@@ -35,7 +36,10 @@ _LOGGER = logging.getLogger(__name__)
 class AbiCompatibilitySieve(Sieve):
     """Remove packages if the image being used doesn't have necessary ABI."""
 
-    image_symbols = attr.ib(type=Set[str], factory=set)  # type: ignore
+    image_symbols = attr.ib(type=Set[str], factory=set, init=False)
+    _messages_logged = attr.ib(type=Set[Tuple[str, str, str]], factory=set, init=False)
+
+    _LINK = jl("abi_missing")
 
     @classmethod
     def should_include(cls, builder_context: "PipelineBuilderContext") -> Optional[Dict[str, Any]]:
@@ -56,6 +60,7 @@ class AbiCompatibilitySieve(Sieve):
                 python_version=runtime_environment.python_version,
             )
         )
+        self._messages_logged.clear()
 
         _LOGGER.debug("Analyzed image has the following symbols: %r", self.image_symbols)
 
@@ -78,8 +83,11 @@ class AbiCompatibilitySieve(Sieve):
                 yield pkg_vers
             else:
                 # Log removed package
-                _LOGGER.debug(
-                    "Removed package %r-%r due to missing symbols.", pkg_vers.name, pkg_vers.version,
-                )
-                _LOGGER.debug("The following symbols are not present: %r", str(missing_symbols))
+                package_tuple = pkg_vers.to_tuple()
+                if package_tuple not in self._messages_logged:
+                    message = f"Package {package_tuple} was removed due to missing ABI symbols in the environment"
+                    _LOGGER.warning("%s - see %s", message, self._LINK)
+                    self._messages_logged.add(package_tuple)
+                    _LOGGER.debug("The following symbols are not present: %r", str(missing_symbols))
+
                 continue
